/* _dict.cc 06/01/1998 00.31.46 */
/* mrtg.cc 30/07/1998 11.04.48 */
PUBLIC MODULE_MRTG::MODULE_MRTG (void);
PUBLIC void MODULE_MRTG::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_MRTG::domenu (MENU_CONTEXT context, const char *key);
/* mrtg_loadavg.cc 19/04/1999 09.11.22 */
/* mrtg_memory.cc 12/12/1999 22.25.54 */
/* mrtg_nbproc.cc 12/12/1999 22.24.34 */
/* mrtg_processes.cc 12/12/1999 22.24.34 */
/* mrtgedit.cc 07/08/2000 00.32.04 */
PRIVATE void MRTG_CONF::init (void);
PUBLIC MRTG_CONF::MRTG_CONF (const char *_id);
PUBLIC MRTG_CONF::MRTG_CONF (void);
PUBLIC bool MRTG_CONF::is_snmp (void);
PUBLIC void MRTG_CONF::target2snmp (SNMPINFO&sn);
PUBLIC void MRTG_CONF::target2command (SSTRING&command);
PUBLIC MRTG_CONF *MRTG_CONFS::getitem (int no)const;
PUBLIC MRTG_CONF *MRTG_CONFS::getitem (const char *id)const;
PUBLIC MRTG_CONFS::MRTG_CONFS (void);
PUBLIC int MRTG_CONF::edit (void);
PUBLIC int MRTG_CONFS::write (void);
PUBLIC int MRTG_CONFS::edit (void);
